.. image:: https://images.unsplash.com/photo-1581059729226-c493d3086748
  :width: 700
  :alt: Alternative text

.. image:: https://img.shields.io/pypi/v/Okazaki.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/Okazaki/
.. image:: https://github.com/Clivern/Okazaki/actions/workflows/ci.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/Clivern/Okazaki/actions/workflows/ci.yml

|

========
Okazaki
========

    Github Automation Package in Python Powered By AI.


Note
====

This Project is Read Only and a Part of Ropen Core.
